@@ -6,7 +6,7 @@ package Dist::Zilla::Role::Author::CSSON::GithubActions;
 
 # ABSTRACT: Role for Github Actions workflows
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -100,7 +100,12 @@ has generated_yaml => (
 # Override this in the Workflow if needed
 sub parse_custom_parameters { }
 
-sub distribution_name { shift->zilla->name }
+sub distribution_name {
+    my $self = shift;
+    my $name = $self->meta->name;
+    $name =~ s/::/-/g;
+    return $name;
+}
 
 sub _prepare {
     my $self = shift;
@@ -185,7 +190,7 @@ Dist::Zilla::Role::Author::CSSON::GithubActions - Role for Github Actions workfl
 
 =head1 VERSION
 
-Version 0.0105, released 2020-12-26.
+Version 0.0106, released 2020-12-26.
 
 =head1 SYNOPSIS
 
